@@ -126,11 +126,11 @@ class Client():
             return str(outp)
 
         try:
-            return _recv(), None
+            return {"code": 200, "response": _recv(buffer), "error": None},
         except ConnectionResetError as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
         except socket.timeout as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
         except Exception:
             raise Exception
 
