@@ -111,22 +111,22 @@ class _ClientOOP():
             return str(outp)
 
         try:
-            return _recv(buffer), None
+            return {"code": 200, "response": _recv(buffer), "error": None},
 
         except ConnectionAbortedError as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
 
         except ConnectionResetError as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
     
         except OSError as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
     
         except WindowsError as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
 
         except socket.timeout as e:
-            return 500, e
+            return {"code": 500, "response": None, "error": e},
 
         except Exception as e:
             raise e
@@ -268,6 +268,10 @@ class Server():
     def ip(self):
         return self.IP
     
+    @property
+    def ngrok_url(self):
+        return self.PUBLIC_URL
+    
     @property
     def connected_clients(self):
         return self.clients
